EnhancedLinkBuilder class

Enhanced builder for link nodes with hover effects

Inheritance

Constructors

EnhancedLinkBuilder({bool showExternalIcon = true})
Creates a new enhanced link builder
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showExternalIcon bool
final

Methods

build(MarkdownNode node, MarkdownStyleSheet styleSheet, MarkdownRenderContext context) Widget
Builds a widget from a Markdown node
override
canBuild(MarkdownNode node) bool
Checks if this builder can handle the given node type
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited