GanttTaskStatus enum

Data models for Gantt Chart diagrams Represents the status of a task

Inheritance
Available extensions

Values

done → const GanttTaskStatus

Task is done

active → const GanttTaskStatus

Task is active/in progress

critical → const GanttTaskStatus

Task is critical

milestone → const GanttTaskStatus

Task is a milestone

normal → const GanttTaskStatus

Normal task

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<GanttTaskStatus>
A constant List of the values in this enum, in order of their declaration.