KanbanParser class

Parser for Mermaid Kanban diagrams

Constructors

KanbanParser()
Creates a Kanban parser
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(List<String> lines) → (MermaidDiagramData, KanbanChartData)?
Parses Kanban diagram from cleaned lines Returns tuple of (MermaidDiagramData, KanbanChartData) or null if invalid
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited