LayoutEngine class abstract

Abstract base class for layout engines

Implementers

Constructors

LayoutEngine()
Creates a layout engine
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

computeLayout(MermaidDiagramData diagram, MermaidStyle style, Size availableSize) Size
Computes layout for the given diagram
measureNode(MermaidNode node, MermaidStyle style) Size
Measures the size of a node
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited