LinkNode class

Represents a link node

Inheritance

Constructors

LinkNode({required String url, required List<MarkdownNode> children, String? title})
Creates a new link node
const

Properties

children List<MarkdownNode>
The link text as child nodes
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
Optional title attribute
final
type String
The type identifier for this node
no setteroverride
url String
The URL
final

Methods

copyWith({String? url, List<MarkdownNode>? children, String? title}) LinkNode
Creates a copy of this node
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this node to a JSON representation
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited