MarkdownBlockPasteResult class

Result of inserting parsed blocks into a text range.

Constructors

MarkdownBlockPasteResult({required MarkdownDocument document, required int selectionOffset})
Creates a block paste result.
const

Properties

document MarkdownDocument
Updated document.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectionOffset int
Markdown-source offset inside the top-level container after the paste.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited