MarkdownEmphasis class

Emphasis/italic inline node.

Inheritance

Constructors

MarkdownEmphasis(List<MarkdownInlineNode> children)
Creates emphasis inline content.
const

Properties

children List<MarkdownInlineNode>
Child inline nodes.
final
hashCode int
The hash code for this object.
no setterinherited
plainText String
User-visible plain text.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
Inline type identifier.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this inline node to JSON.
override
toMarkdown() String
Serializes this inline node to Markdown.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited