MarkdownParagraphBlock class

Paragraph block.

Inheritance

Constructors

MarkdownParagraphBlock({required String id, required List<MarkdownInlineNode> children})
Creates a paragraph block.
const

Properties

children List<MarkdownInlineNode>
Inline content.
final
hashCode int
The hash code for this object.
no setterinherited
id String
Stable block identifier used by selections and transactions.
finalinherited
plainText String
User-visible plain text.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
Block type identifier.
no setteroverride

Methods

copyWith({String? id, List<MarkdownInlineNode>? children}) MarkdownParagraphBlock
Returns a copy with updated fields.
findBlock(String blockId) MarkdownBlock?
Finds blockId in this block or its children.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replaceNestedBlock(MarkdownBlock replacement) MarkdownBlock
Replaces a nested block. Blocks without children return themselves.
inherited
replaceNestedBlockWithBlocks(String blockId, List<MarkdownBlock> replacements) MarkdownBlock
Replaces a nested block with several blocks.
inherited
toJson() Map<String, dynamic>
Converts this block to a serializable map.
override
toMarkdown() String
Serializes this block to Markdown.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited