MarkdownSelectionTransactionResult class

Result of applying a document-wide selection transaction.

Constructors

MarkdownSelectionTransactionResult({required MarkdownDocument document, required String activeBlockId, required int selectionOffset})
Creates a selection transaction result.
const

Properties

activeBlockId String
Block that should become active after the transaction.
final
document MarkdownDocument
Updated document.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectionOffset int
Plain-text cursor offset inside activeBlockId.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited