MermaidDeviceConfig class

Device-specific configuration

Constructors

MermaidDeviceConfig({required DeviceType deviceType, required double padding, required double nodeSpacingX, required double nodeSpacingY, required double fontSize, required double titleFontSize, required double minNodeWidth, required double minNodeHeight, required double participantSpacing, required double messageSpacing, required double pieMinRadius, required double legendFontSize, required double scaleFactor, required bool showLegendBelow})
Creates device config
const
MermaidDeviceConfig.desktop()
Desktop configuration
const
MermaidDeviceConfig.mobile()
Mobile configuration
const
MermaidDeviceConfig.tablet()
Tablet configuration
const

Properties

deviceType DeviceType
Device type
final
fontSize double
Base font size for labels
final
hashCode int
The hash code for this object.
no setterinherited
legendFontSize double
Font size for legend text
final
messageSpacing double
Spacing between messages in sequence diagrams
final
minNodeHeight double
Minimum node height
final
minNodeWidth double
Minimum node width
final
nodeSpacingX double
Horizontal spacing between nodes
final
nodeSpacingY double
Vertical spacing between nodes
final
padding double
Padding around the diagram
final
participantSpacing double
Spacing between participants in sequence diagrams
final
pieMinRadius double
Minimum pie chart radius
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scaleFactor double
Overall scale factor
final
showLegendBelow bool
Whether to show legend below the chart (for mobile)
final
titleFontSize double
Font size for titles
final

Methods

copyWith({DeviceType? deviceType, double? padding, double? nodeSpacingX, double? nodeSpacingY, double? fontSize, double? titleFontSize, double? minNodeWidth, double? minNodeHeight, double? participantSpacing, double? messageSpacing, double? pieMinRadius, double? legendFontSize, double? scaleFactor, bool? showLegendBelow}) MermaidDeviceConfig
Creates a copy with modified properties
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited