ParserPlugin class abstract

Base interface for parser plugins

Parser plugins extend the markdown parser with custom syntax. Implement either BlockParserPlugin or InlineParserPlugin depending on the type of syntax you want to add.

Implementers

Constructors

ParserPlugin()
Creates a new parser plugin
const

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
Unique identifier for this plugin
no setter
name String
Human-readable name for this plugin
no setter
priority int
Priority of this plugin (higher = checked first)
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited