PieChartColors class

Default color palette for pie charts

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getColor(int index) int
Gets a color from the palette by index

Constants

defaultPalette → const List<int>
Default color palette (Material Design colors)