PieChartData class

Data for a complete pie chart

Constructors

PieChartData({String? title, required List<PieSlice> slices, bool showValuesInLegend = true})
Creates pie chart data
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showValuesInLegend bool
Whether to show values in the legend
final
slices List<PieSlice>
All slices in the pie chart
final
title String?
Optional title for the pie chart
final
totalValue double
Gets the total value of all slices
no setter

Methods

copyWith({String? title, List<PieSlice>? slices, bool? showValuesInLegend}) PieChartData
Creates a copy with modified properties
getPercentage(PieSlice slice) double
Gets the percentage for a slice
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited