PieSlice class

Data models for Pie Chart diagrams Represents a single slice in a pie chart

Constructors

PieSlice({required String label, required double value, int? color})
Creates a pie slice
const

Properties

color int?
Optional custom color (ARGB int)
final
hashCode int
The hash code for this object.
no setterinherited
label String
Label for this slice
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value double
Value (determines the size of the slice)
final

Methods

copyWith({String? label, double? value, int? color}) PieSlice
Creates a copy with modified properties
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited