SimpleLayoutEngine class
Simple layout engine that arranges nodes in a grid-like pattern
This is a basic fallback layout when more sophisticated algorithms aren't needed or available.
- Inheritance
-
- Object
- LayoutEngine
- SimpleLayoutEngine
Constructors
- SimpleLayoutEngine()
-
Creates a simple layout engine
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
computeLayout(
MermaidDiagramData diagram, MermaidStyle style, Size availableSize) → Size -
Computes layout for the given diagram
override
-
measureNode(
MermaidNode node, MermaidStyle style) → Size -
Measures the size of a node
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited