TableNode class

Represents a table node

Inheritance

Constructors

TableNode({required List<List<MarkdownNode>> headers, required List<TableAlignment?> alignments, required List<TableRowNode> rows})
Creates a new table node
const

Properties

alignments List<TableAlignment?>
Column alignments (left, center, right, null for default)
final
hashCode int
The hash code for this object.
no setterinherited
headers List<List<MarkdownNode>>
Table header cells
final
rows List<TableRowNode>
Table data rows
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
The type identifier for this node
no setteroverride

Methods

copyWith({List<List<MarkdownNode>>? headers, List<TableAlignment?>? alignments, List<TableRowNode>? rows}) TableNode
Creates a copy of this node
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this node to a JSON representation
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited