MarkdownDocumentCodec class
Markdown import/export bridge for MarkdownDocument.
Constructors
- MarkdownDocumentCodec({ParserPluginRegistry? plugins})
- Creates a document codec.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parse(
String markdown) → MarkdownDocument -
Parses
markdowninto an editable document tree. -
serialize(
MarkdownDocument document) → String -
Serializes
documentto Markdown. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited