MarkdownEditorCapabilities class

Configures which built-in editor commands are available.

Constructors

MarkdownEditorCapabilities({Set<MarkdownEditorCommand> disabledCommands = const <MarkdownEditorCommand>{}})
Creates a command availability configuration.
const

Properties

disabledCommands Set<MarkdownEditorCommand>
Built-in commands hidden from UI and ignored by shortcuts/slash commands.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
supports(MarkdownEditorCommand command) bool
Whether command is available to the editor.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

all → const MarkdownEditorCapabilities
Default configuration with every built-in command enabled.