MarkdownEditorCustomBlockContext class

Constructors

MarkdownEditorCustomBlockContext({required String blockId, required String blockType, required String markdown, required String plainText, required bool enabled, required VoidCallback edit, required ValueChanged<String> replaceMarkdown, required VoidCallback delete})
Creates context for a custom block view.
const

Properties

blockId String
Stable document block id.
final
blockType String
Document block type.
final
delete VoidCallback
Deletes this block.
final
edit VoidCallback
Activates the formatted editor for this block.
final
enabled bool
Whether editing commands are enabled.
final
hashCode int
The hash code for this object.
no setterinherited
markdown String
Markdown source for this block.
final
plainText String
Visible plain text for this block, when available.
final
replaceMarkdown ValueChanged<String>
Replaces this block with markdown.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited