MarkdownEditorImageSelection class

Image data returned by SmoothMarkdownEditor.onPickImage.

Constructors

MarkdownEditorImageSelection({required String url, String alt = '', String? title})
Creates image data for insertion.
const

Properties

alt String
Optional alt text. When empty, the current selected text is used.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
Optional Markdown image title.
final
url String
URL or asset path to write into the Markdown image.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited