mode property
Controlled editor display mode.
When null, the editor owns its mode and starts from initialMode.
Implementation
final MarkdownEditorMode? mode;
Controlled editor display mode.
When null, the editor owns its mode and starts from initialMode.
final MarkdownEditorMode? mode;