onExportMarkdown property

MarkdownEditorMarkdownExportCallback? onExportMarkdown
final

Called when the export menu requests a Markdown file export.

If omitted, the export action copies the Markdown source to the clipboard.

Implementation

final MarkdownEditorMarkdownExportCallback? onExportMarkdown;