onPerformanceSnapshot property
Called after editor state changes with lightweight performance telemetry.
Implementation
final MarkdownEditorPerformanceCallback? onPerformanceSnapshot;
Called after editor state changes with lightweight performance telemetry.
final MarkdownEditorPerformanceCallback? onPerformanceSnapshot;