isAttached property
bool
get
isAttached
Whether this controller is currently attached to a mounted SmoothSelectionRegion.
Implementation
bool get isAttached => _state != null;
Whether this controller is currently attached to a mounted SmoothSelectionRegion.
bool get isAttached => _state != null;