magnifierConfiguration property
The configuration for the magnifier used with selections in this region.
Implementation
final TextMagnifierConfiguration? magnifierConfiguration;
The configuration for the magnifier used with selections in this region.
final TextMagnifierConfiguration? magnifierConfiguration;