selectionControls property
The delegate to build the selection handles and toolbar for mobile devices.
If it is null, a platform-specific selection control is used.
Implementation
final TextSelectionControls? selectionControls;
The delegate to build the selection handles and toolbar for mobile devices.
If it is null, a platform-specific selection control is used.
final TextSelectionControls? selectionControls;