EmojiNode class
AST node representing an emoji shortcode
- Inheritance
-
- Object
- MarkdownNode
- EmojiNode
Constructors
Properties
- emoji → String
-
The resolved emoji character(s)
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shortcode → String
-
The shortcode (without colons)
final
- type → String
-
The type identifier for this node
no setteroverride
Methods
-
copyWith(
{String? shortcode, String? emoji}) → EmojiNode -
Creates a copy of this node
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts this node to a JSON representation
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited