GanttTask class
Represents a single task in a Gantt chart
Constructors
Properties
-
dependencies
→ List<
String> -
List of task IDs this task depends on
final
- durationDays → int
-
Gets the duration in days
no setter
- endDate → DateTime
-
End date of the task
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Unique identifier for this task
final
- name → String
-
Display name of the task
final
- progress → int
-
Progress percentage (0-100)
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- section → String?
-
Optional section this task belongs to
final
- startDate → DateTime
-
Start date of the task
final
- status → GanttTaskStatus
-
Status of the task
final
Methods
-
copyWith(
{String? id, String? name, DateTime? startDate, DateTime? endDate, String? section, GanttTaskStatus? status, List< String> ? dependencies, int? progress}) → GanttTask - Creates a copy with modified properties
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited