ListItemNode class
Represents a list item node
- Inheritance
-
- Object
- MarkdownNode
- ListItemNode
Constructors
-
ListItemNode({required List<
MarkdownNode> children, bool? checked}) -
Creates a new list item node
const
Properties
- checked → bool?
-
For task lists, whether the item is checked
final
-
children
→ List<
MarkdownNode> -
The child nodes
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String
-
The type identifier for this node
no setteroverride
Methods
-
copyWith(
{List< MarkdownNode> ? children, bool? checked}) → ListItemNode -
Creates a copy of this node
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts this node to a JSON representation
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited