MarkdownListBlock class
List block.
- Inheritance
-
- Object
- MarkdownBlock
- MarkdownListBlock
Constructors
-
MarkdownListBlock({required String id, required MarkdownListKind kind, required List<
MarkdownListItem> items, int startIndex = 1}) -
Creates a list block.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Stable block identifier used by selections and transactions.
finalinherited
-
items
→ List<
MarkdownListItem> -
List items.
final
- kind → MarkdownListKind
-
List kind.
final
- plainText → String
-
User-visible plain text.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startIndex → int
-
Ordered list start index.
final
- type → String
-
Block type identifier.
no setteroverride
Methods
-
copyWith(
{String? id, MarkdownListKind? kind, int? startIndex, List< MarkdownListItem> ? items}) → MarkdownListBlock - Returns a copy with updated fields.
-
findBlock(
String blockId) → MarkdownBlock? -
Finds
blockIdin this block or its children.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
replaceNestedBlock(
MarkdownBlock replacement) → MarkdownBlock -
Replaces a nested block. Blocks without children return themselves.
override
-
replaceNestedBlockWithBlocks(
String blockId, List< MarkdownBlock> replacements) → MarkdownBlock -
Replaces a nested block with several blocks.
override
-
toJson(
) → Map< String, dynamic> -
Converts this block to a serializable map.
override
-
toMarkdown(
) → String -
Serializes this block to Markdown.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited