MarkdownSplitBlockResult class
Result of splitting an editable block at the caret.
Constructors
- MarkdownSplitBlockResult({required MarkdownDocument document, required String activeBlockId, required int selectionOffset})
-
Creates a split-block result.
const
Properties
- activeBlockId → String
-
Block that should become active after the split.
final
- document → MarkdownDocument
-
Updated document.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectionOffset → int
-
Local selection offset inside the active block.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited