MermaidDiagramNode class
AST node for Mermaid diagrams
- Inheritance
-
- Object
- MarkdownNode
- MermaidDiagramNode
Constructors
- MermaidDiagramNode({required String code, String? theme, String fence = '```', String? info})
-
Creates a new Mermaid diagram node
const
Properties
- code → String
-
The Mermaid diagram code
final
- fence → String
-
The fence marker used for this Mermaid block.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- info → String?
-
Full Mermaid fence info string, including
mermaid.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- theme → String?
-
Optional theme name (light, dark, forest, neutral)
final
- type → String
-
The type identifier for this node
no setteroverride
Methods
-
copyWith(
{String? code, String? theme, String? fence, String? info}) → MermaidDiagramNode -
Creates a copy of this node
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts this node to a JSON representation
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited