SubgraphStyle class
Style for subgraphs
Constructors
Properties
- backgroundColor → int?
-
Background color
final
- borderColor → int?
-
Border color
final
- borderRadius → double
-
Border radius
final
- borderWidth → double
-
Border width
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- padding → double
-
Padding inside the subgraph
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited