MarkdownEditorImagePickEvent class
Image picking/insertion lifecycle event.
Constructors
- MarkdownEditorImagePickEvent({required MarkdownEditorImagePickStatus status, MarkdownEditorImageSelection? selection, Object? error, StackTrace? stackTrace})
-
Creates an image picking/insertion lifecycle event.
const
Properties
- error → Object?
-
Error thrown by a host picker/uploader when the status is failed.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selection → MarkdownEditorImageSelection?
-
Selected image when available.
final
- stackTrace → StackTrace?
-
Stack trace associated with error.
final
- status → MarkdownEditorImagePickStatus
-
Current lifecycle status.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited