MarkdownEditorMode enum
Display mode for SmoothMarkdownEditor.
Values
- formatted → const MarkdownEditorMode
-
Rendered Markdown blocks that become editable when focused.
- source → const MarkdownEditorMode
-
Raw Markdown source only.
- preview → const MarkdownEditorMode
-
Rendered Markdown preview only.
- split → const MarkdownEditorMode
-
Source editor and rendered preview side by side when space allows.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
MarkdownEditorMode> - A constant List of the values in this enum, in order of their declaration.