onExportMarkdown property
Called when the export menu requests a Markdown file export.
If omitted, the export action copies the Markdown source to the clipboard.
Implementation
final MarkdownEditorMarkdownExportCallback? onExportMarkdown;
Called when the export menu requests a Markdown file export.
If omitted, the export action copies the Markdown source to the clipboard.
final MarkdownEditorMarkdownExportCallback? onExportMarkdown;